@@ -65,7 +65,7 @@
 #' 
 #' # Example: Distance Matrix using KL-Distance
 #' 
-#' Prob <- cbind(1:10/sum(1:10), 20:29/sum(20:29), 30:39/sum(30:39))
+#' Prob <- rbind(1:10/sum(1:10), 20:29/sum(20:29), 30:39/sum(30:39))
 #'
 #' # compute the KL matrix of a given probability matrix
 #' KLMatrix <- KL(Prob)
@@ -79,7 +79,7 @@
 KL <- function(x, test.na = TRUE, unit = "log2", est.prob = NULL){
         if (!is.matrix(x))
           stop("Please provide a matrix as input, e.g. with x <- rbind(vector1, vector2).", call. = FALSE)
-        message("Kulback-Leibler Divergence using unit '", unit, "'.")
+        
         return( distance( x           = x,
                           method      = "kullback-leibler",
                           test.na     = test.na,
